@@ -191,6 +191,7 @@ create_new_key (char *key_string)
       fprintf (stderr, "Unable to allocate memory for key!\n");
       exit (1);
     }
+
   k->next = NULL;
 
   if (key == NULL)
@@ -252,26 +253,28 @@ create_new_key (char *key_string)
 	k->modifier = k->modifier | ControlMask;
       if (key_str[2] == '*')
 	k->modifier = k->modifier | Mod1Mask;
+      if (key_str[3] == '*')
+	k->modifier = k->modifier | Mod4Mask;
     }
 
-  if ((strlen (key_str) > 11) && (strncmp (key_str+3, "Released ", 9) == 0))
+  if ((strlen (key_str) > 12) && (strncmp (key_str+4, "Released ", 9) == 0))
     {
-      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 12));
+      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 13));
       k->type = 3;
     }
-  else if ((strlen (key_str) > 11) && (strncmp (key_str+3, "Pressed ", 8) == 0))
+  else if ((strlen (key_str) > 12) && (strncmp (key_str+4, "Pressed ", 8) == 0))
     {
-      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 11));
+      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 12));
       k->type = 2;
     }
-  else if ((strlen (key_str) > 8) && (strncmp (key_str+3, "Held ", 5) == 0))
+  else if ((strlen (key_str) > 9) && (strncmp (key_str+4, "Held ", 5) == 0))
     {
-      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 8));
+      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 9));
       k->type = 1;
     }
-  else if ((strlen (key_str) > 11) && (strncmp (key_str+3, "Combine ", 8) == 0))
+  else if ((strlen (key_str) > 12) && (strncmp (key_str+4, "Combine ", 8) == 0))
     {
-      char *sep = strchr (key_str + 11, ' ');
+      char *sep = strchr (key_str + 12, ' ');
       if (sep)
 	{
 	  *sep = 0;
@@ -279,13 +282,13 @@ create_new_key (char *key_string)
 	}
       else
 	k->keycode2 = 0;
-      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 11));
+      k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (key_str + 12));
       k->type = 4;
     }
   else
     {
       if (key_str && strlen (key_str))
-        k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (g_strstrip(key_str + 3)));
+        k->keycode = XKeysymToKeycode (dpy, XStringToKeysym (g_strstrip(key_str + 4)));
       k->type = 0;
     }
 
@@ -562,7 +565,7 @@ void process_key (XEvent ev, int type)
 #endif
 
 	  ev.xkey.state =
-	    ev.xkey.state & (Mod1Mask | ControlMask | ShiftMask);
+	    ev.xkey.state & (ControlMask | ShiftMask | Mod1Mask | Mod4Mask);
 	  for (k = key; k != NULL; k = k->next)
 	    if (k->keycode == ev.xkey.keycode
 		&& (k->modifier == AnyModifier
@@ -583,7 +586,8 @@ void process_key (XEvent ev, int type)
 #ifdef DEBUG
 		    printf ("running program\n");
 #endif
-		    gpe_launch_program_with_callback (dpy, k->command, k->command, TRUE, NULL, NULL);
+		    gpe_launch_program_with_callback (dpy, k->command, k->command, 
+			                                  k->startup_notify, NULL, NULL);
 		  }
 
 		k = lastkey;
